@@ -1077,7 +1077,7 @@ class Askdata(SignUp):
                 return None
 
 
-        url = self.base_url + "/smartbot/agents/"+agent_id+"/v2/ask"
+        url = self.base_url + "/smartbot/agent-slug/"+workspace+"/v2/ask"
 
         s = requests.Session()
         s.keep_alive = False
